{% load i18n filebrowser %}

<h2>{% trans "Filter" %}</h2>
<dl>
  <dt>{% trans "Date" %}</dt>
  <dd{% if not query.filter_date %} class="active"{% endif %}><a href="{% query_string 'filter_date,p' %}">{% trans "Any Date" %}</a></dd>
  <dd{% if query.filter_date == 'today' %} class="active"{% endif %}><a href="{% query_string 'filter_date,p' %}&amp;filter_date=today">{% trans "Today" %}</a></dd>
  <dd{% if query.filter_date == 'past7days' %} class="active"{% endif %}><a href="{% query_string 'filter_date,p' %}&amp;filter_date=past7days">{% trans "Past 7 days" %}</a></dd>
  <dd{% if query.filter_date == 'thismonth' %} class="active"{% endif %}><a href="{% query_string 'filter_date,p' %}&amp;filter_date=thismonth">{% trans "Past 30 days" %}</a></dd>
  <dd{% if query.filter_date == 'thisyear' %} class="active"{% endif %}><a href="{% query_string 'filter_date,p' %}&amp;filter_date=thisyear">{% trans "This year" %}</a></dd>
</dl>
