{% load i18n filebrowser %}

{% if page_range %}
  {% for i in page_range %}
    {% if i == "." %}
      <span>...</span>
    {% else %}
      <a{% if i == page_num %} class="active"{% endif %} href="{% query_string 'p' %}&amp;p={{ i|add:"1" }}">{{ i|add:"1" }}</a>
    {% endif %}
  {% endfor %}
{% endif %}
<span>{% blocktrans count results_var.results_total as counter %}{{ counter }} item{% plural %}{{ counter }} items{% endblocktrans %}</span>
